..  Copyright (C)  Brad Miller, David Ranum, Jeffrey Elkner, Peter Wentworth, Allen B. Downey, Chris
    Meyers, and Dario Mitchell.  Permission is granted to copy, distribute
    and/or modify this document under the terms of the GNU Free Documentation
    License, Version 1.3 or any later version published by the Free Software
    Foundation; with Invariant Sections being Forward, Prefaces, and
    Contributor List, no Front-Cover Texts, and no Back-Cover Texts.  A copy of
    the license is included in the section entitled "GNU Free Documentation
    License".

.. qnum::
   :prefix: intro-8-
   :start: 1

👩‍💻 Predict Before You Run!
=============================

You've run your first program! You'll be doing that a lot in this book and the programs will become increasingly 
complicated. One way to help understand what is happening and learn programming is predicting the effect of running a 
snippet of code before actually running the program. Later on in your development, you may make predictions about large 
snippets of code, but for now you will typically be predicting the effect of executing a single line of code. A prediction 
will either be about what gets printed out, or about the value of a variable, or that an error will occur.

A prediction is not a random guess. It is based on some explanation you have about what the current state of 
variables is and about what you think certain commands in python do.

While you read the textbook you'll see chapters, pages, or snippets of text that begin with "WP:". This denotes sections 
that talk about the Way of the Programmer: advice or information that will help you to be a better programmer and make 
better programs. Be on the lookout for other WP pages!
